import 'package:auto_direction/auto_direction.dart';
import 'package:blox/constants/package_config.dart';
import 'package:blox/constants/supporting_fonts.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart' as intl;

class BloxTextView extends StatelessWidget {
  final String text;
  final bool multiLine;
  final TextStyle style;
  const BloxTextView({Key key, this.text, this.multiLine, this.style})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Text(
          text,
          textDirection: isRTL(text) ? TextDirection.rtl : TextDirection.ltr,
          textAlign: isRTL(text) ? TextAlign.right : TextAlign.left,
          style: style,
        ),
        SizedBox(
          height: 16,
        ),
      ],
    );
  }
}

class BloxTextEditor extends StatefulWidget {
  final String text;
  final double textSize;
  final Function(String value) onChange;
  final bool multiLine;
  const BloxTextEditor(
      {Key key, this.text, this.onChange, this.textSize = 16, this.multiLine})
      : super(key: key);
  @override
  _BloxTextEditorState createState() => _BloxTextEditorState();
}

class _BloxTextEditorState extends State<BloxTextEditor> {
  TextEditingController _textEditingController = TextEditingController();
  int lines = 1;
  String vlue = "";
  @override
  void initState() {
    super.initState();
    if (widget.multiLine)
      lines = '\n'.allMatches(widget.text).length == 0
          ? 2
          : '\n'.allMatches(widget.text).length + 1;
    _textEditingController.text = widget.text;
    vlue = widget.text;
  }

  @override
  Widget build(BuildContext context) {
    return AutoDirection(
      text: vlue.isEmpty ? "L" : vlue,
      child: TextFormField(
        textDirection: isRTL(vlue) ? TextDirection.rtl : TextDirection.ltr,
        textAlign: (!widget.multiLine)
            ? TextAlign.center
            : isRTL(vlue) ? TextAlign.right : TextAlign.left,
        enableSuggestions: true,
        cursorColor: Colors.red,
        cursorWidth: 1,
        showCursor: true,
        maxLines: lines,
        style: TextStyle(
            fontFamily: isRTL(vlue) ? BloxFonts.iranSans : BloxFonts.raleWay,
            package: PackageConfig.PACKAGE_NAME,
            fontSize: widget.textSize),
        decoration: InputDecoration(
            border: InputBorder.none, hintText: "Type Somthing ..."),
        controller: _textEditingController,
        onChanged: (value) {
          if (widget.multiLine)
            lines = '\n'.allMatches(value).length == 0
                ? 2
                : '\n'.allMatches(value).length + 1;
          setState(() {
            vlue = value;
          });
          widget.onChange(value);
        },
      ),
    );
  }
}

bool isRTL(String text) {
  return intl.Bidi.detectRtlDirectionality(text);
}
